@@ -1,6 +1,6 @@
 import importlib.metadata
 
-from celldega.viz import Landscape, Toy
+from celldega.viz import Landscape, Matrix
 from celldega.pre import landscape
 
 try:
@@ -8,4 +8,4 @@ try:
 except importlib.metadata.PackageNotFoundError:
     __version__ = "unknown"
 
-__all__ = ["Landscape", "Toy", "landscape"]
\ No newline at end of file
+__all__ = ["Landscape", "landscape", "Matrix"]
